import configPromise from '@payload-config'
import { getPayload, type RequiredDataFromCollectionSlug } from 'payload'
import { draftMode } from "next/headers";
import { cache } from "react";
import { RenderBlocks } from "@/blocks/RenderBlocks";
import PageClient from "./page.client";


export async function generateStaticParams() {
  const payload = await getPayload({ config: configPromise })
  const pages = await payload.find({
    collection: 'pages',
    draft: false,
    limit: 1000,
    overrideAccess: false,
    pagination: false,
    select: {
      slug: true,
    },
  })

  const params = pages.docs
    ?.filter((doc) => {
      return doc.slug !== 'home'
    })
    .map(({ slug }) => {
      return { slug }
    })

  return params
}

const queryPageBySlug = cache(async ({ slug }: { slug: string }) => {
  const { isEnabled: draft } = await draftMode()

  const payload = await getPayload({ config: configPromise })

  const result = await payload.find({
    collection: 'pages',
    draft,
    limit: 1,
    pagination: false,
    overrideAccess: draft,
    where: {
      slug: {
        equals: slug,
      },
    },
  })

  return result.docs?.[0] || null
})

type Args = {
  params: Promise<{
    slug?: string
  }>
}

export default async function Page({ params: paramsPromise }: Args) {
  const { slug = 'home' } = await paramsPromise
  
  //const { isEnabled: draft } = await draftMode()
  //const url = '/' + slug

  const page: RequiredDataFromCollectionSlug<'pages'> | null  = await queryPageBySlug({
    slug,
  }) || null

  if (!page) {
    return <div /> //  return <PayloadRedirects url={url} />
  }

  const { layout } = page

  return (
    <article className="flex flex-col min-h-[100dvh] space-y-10"  >
      <PageClient />
      {/* Allows redirects for valid pages too */}
      {/*<PayloadRedirects disableNotFound url={url} />*/}
      {/*draft && <LivePreviewListener />*/}

      <RenderBlocks blocks={layout} />
    </article>
  )
}

