import { Badge } from '@/components/ui/badge'
import BlurFade from '@/components/ui/blur-fade'
import { BadgeListBlock as BadgeListProps } from '@/payload-types'
import clsx from 'clsx'

const BLUR_FADE_DELAY = 0.04

type Props = { className?: string } & BadgeListProps
export const BadgeList = (props: Props) => {
  return (
    <section id={props.blockName || ''} className="mt-1">
      <div className="flex flex-col gap-y-3">
        {!props.shouldHideListHeader && (
          <BlurFade delay={BLUR_FADE_DELAY * 9}>
            <h2 className="text-xl font-bold">{props.listHeader}</h2>
          </BlurFade>
        )}
        <div className="flex flex-wrap gap-1">
          {props.badges?.map((b, id) => (
            <BlurFade key={b.id} delay={BLUR_FADE_DELAY * 10 + id * 0.05}>
              <Badge
                className={clsx(props.textSize ? props.textSize : '')}
                variant={props.listVariant || 'default'}
              >
                {b.value}
              </Badge>
            </BlurFade>
          ))}
        </div>
      </div>
    </section>
  )
}
