import React, { Fragment } from 'react'

import type { Page } from '@/payload-types'
import { SimpleBrief } from './SimpleBrief/component'
import { SimpleList } from './SimpleList/component'
import { Showcase } from './Showcase/component'
import { ProfileBrief } from './ProfileBrief/component'
import { BadgeList } from './BadgeList/component'
import { ContactForm } from './ContactForm/component'

const blockComponents = {
  simpleBrief: SimpleBrief,
  simpleList: SimpleList,
  showcase: Showcase,
  profileBrief: ProfileBrief,
  badgeList: BadgeList,
  contactForm: ContactForm,
}

export const RenderBlocks: React.FC<{
  blocks: Page['layout']
}> = (props) => {
  const blocks = Array.from(props.blocks?.values() || [])
  const hasBlocks = blocks && Array.isArray(blocks) && blocks.length > 0
  if (!hasBlocks) return null

  return (
    <Fragment>
      {blocks.map((block, index) => {
        const { blockType } = block

        if (blockType && blockType in blockComponents) {
          const Block = blockComponents[blockType]

          if (Block) {
            return (
              <div key={index}>
                {/* @ts-expect-error there may be some mismatch between the expected types here */}
                <Block {...block} disableInnerContainer />
              </div>
            )
          }
        }
        return null
      })}
    </Fragment>
  )
}
