import { s3Storage } from '@payloadcms/storage-s3'
import { nodemailerAdapter } from '@payloadcms/email-nodemailer'
import { formBuilderPlugin } from '@payloadcms/plugin-form-builder'
import { postgresAdapter } from '@payloadcms/db-postgres'
import path from 'path'
import { buildConfig } from 'payload'
import { fileURLToPath } from 'url'
import sharp from 'sharp'

import { Users } from './collections/Users'
import { Media } from './collections/Media'
import { Pages } from './collections/Pages'
import { defaultLexical } from './fields/defaultLexical'
import { NavGlobal } from './globals/Nav/config'
import { MetaGlobal } from './globals/Meta/config'

import './envConfig.ts'

const filename = fileURLToPath(import.meta.url)
const dirname = path.dirname(filename)

export default buildConfig({
  admin: {
    meta: {
      title: 'ySandler | Custom Software Consultant',
      description: 'Yehoshua Sandler is a custom software consultant helping buisnesses and organizations streamline their workflow and organize theit data by creating beautiful and easy to use software accross the full stack.',
      icons: [
        {
          rel: 'icon',
          url: '/favicon.ico',
        },
      ],
    },
    user: Users.slug,
    importMap: {
      baseDir: path.resolve(dirname),
    },
  },
  collections: [Users, Media, Pages],
  globals: [MetaGlobal, NavGlobal],
  editor: defaultLexical,
  secret: process.env.PAYLOAD_SECRET || '',
  typescript: {
    outputFile: path.resolve(dirname, 'payload-types.ts'),
  },
  db: postgresAdapter({
    pool: {
      connectionString: process.env.DATABASE_URI || '',
    },
  }),
  email: nodemailerAdapter({
    defaultFromAddress: 'no-reply@beitzah.net',
    defaultFromName: 'no-reply Beitzah',
    transportOptions: {
      host: process.env.SMTP_HOST,
      port: parseInt(process.env.SMTP_PORT || '', 10),
      auth: {
        user: process.env.SMTP_USER,
        pass: process.env.SMTP_PASS,
      },
    },
  }),

  sharp,
  plugins: [
    formBuilderPlugin({
      fields: {
        text: true,
        textarea: true,
        select: true,
        email: true,
        state: true,
        country: true,
        checkbox: true,
        number: true,
        message: true,
        payment: false,
      },
      defaultToEmail: process.env.DEFAULT_EMAIL,
      formOverrides: {
        access: {
          read: () => true, // !!user, // authenticated users only
          update: () => false,
        },
      }
    })
  ],
})
